==> phoenix_widgets-1.16.5.tar.gz: example/lib/phoenix_navigation_card_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixNavigationCardPage extends StatefulWidget {
  const PhoenixNavigationCardPage({Key? key}) : super(key: key);

  @override
  State<PhoenixNavigationCardPage> createState() =>
      _PhoenixNavigationCardPageState();
}

class _PhoenixNavigationCardPageState extends State<PhoenixNavigationCardPage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('Phoenix Navigation Card Sample App'),
        ),
        body: Column(
          children: [
            PhoenixNavigationCard(
              isVisible: false,
              icon: SvgPicture.asset(
                "assets/education.svg",
                width: 46,
                height: 46,
              ),
              title: Text(
                "Title",
                style: Theme.of(context).textTheme.headline6,
              ),
              description: Text(
                "Lorem ipsum dolor sit amet, consectetur adipiscing elite!",
                style: Theme.of(context).textTheme.bodyText2,
              ),
              callback: () {},
              navigationText: Text(
                "Click Here",
                style: Theme.of(context).textTheme.bodyText2,
              ),
            ),
          ],
        ));
  }
}

==> phoenix_widgets-1.17.4.tar.gz: example/lib/phoenix_navigation_card_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixNavigationCardPage extends StatefulWidget {
  const PhoenixNavigationCardPage({Key? key}) : super(key: key);

  @override
  State<PhoenixNavigationCardPage> createState() =>
      _PhoenixNavigationCardPageState();
}

class _PhoenixNavigationCardPageState extends State<PhoenixNavigationCardPage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('Phoenix Navigation Card Sample App'),
        ),
        body: Column(
          children: [
            PhoenixNavigationCard(
              isVisible: false,
              icon: SvgPicture.asset(
                "assets/education.svg",
                width: 46,
                height: 46,
              ),
              title: Text(
                "Title",
                style: Theme.of(context).textTheme.titleLarge,
              ),
              description: Text(
                "Lorem ipsum dolor sit amet, consectetur adipiscing elite!",
                style: Theme.of(context).textTheme.bodyMedium,
              ),
              callback: () {},
              navigationText: Text(
                "Click Here",
                style: Theme.of(context).textTheme.bodyMedium,
              ),
            ),
          ],
        ));
  }
}
